@@ -2,38 +2,12 @@ import time
 from typing import Dict
 import requests
 from sky_api_client.entity.base import Entity
-from sky_api_client.entity.address import Address
-from sky_api_client.entity.constituent import Constituent
-from sky_api_client.entity.education import Education
-from sky_api_client.entity.online_presence import OnlinePresence
-from sky_api_client.entity.phone import Phone
-from sky_api_client.entity.relationship import Relationship
-from sky_api_client.entity.email_addresses import EmailAddress
-from sky_api_client.entity.custom_field import CustomField
-from sky_api_client.entity.custom_field_categories import CustomFieldCategory
-from sky_api_client.entity.code_table import CodeTable
-from sky_api_client.entity.table_entry import TableEntry
-from sky_api_client.entity.webhook_subscription import WebhookSubscription
+from sky_api_client.entity.registry import EntityRegistry
 from sky_api_client.exceptions.exception import GeneralError
 
 BASE_URL = 'https://api.sky.blackbaud.com'
 DEFAULT_TIMEOUT = 300
 
-PROPERTIES = {
-    'constituent': Constituent,
-    'education': Education,
-    'phone': Phone,
-    'address': Address,
-    'relationship': Relationship,
-    'email_addresses': EmailAddress,
-    'custom_fields': CustomField,
-    'custom_field_category': CustomFieldCategory,
-    'code_table': CodeTable,
-    'table_entry': TableEntry,
-    'subscription_webhook': WebhookSubscription,
-    'online_presence': OnlinePresence,
-}
-
 
 class SkyApiClient(object):
     def __init__(self, subscription_key: str, access_token: str) -> None:
@@ -76,5 +50,6 @@ class SkyApi(object):
         self._api = SkyApiClient(subscription_key, access_token)
 
     def __getattr__(self, attr: str) -> Entity:
-        if PROPERTIES[attr]:
-            return PROPERTIES[attr](api=self._api)
+        entity_class = EntityRegistry.get_class(attr)
+        if entity_class:
+            return entity_class(api=self._api)
