@@ -6,6 +6,6 @@ from sky_api_client.entity.registry import EntityRegistry
 class Gift(Entity):
     LIST_URL = '/gift/v1/gifts'
     CREATE_URL = '/gift/v1/gifts'
-    GET_URL = '/gift/v1/gift/{id}'
-    UPDATE_URL = '/gift/v1/gift/{id}/'
-    DELETE_URL = '/gift/v1/gift/{id}/'
+    GET_URL = '/gift/v1/gifts/{id}'
+    UPDATE_URL = '/gift/v1/gifts/{id}/'
+    DELETE_URL = '/gift/v1/gifts/{id}/'
